# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['wlang_cli']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.1.0,<9.0.0', 'wcore-py>=0.5.1,<0.6.0']

setup_kwargs = {
    'name': 'wlang-cli',
    'version': '0.1.4',
    'description': 'A cli for the W programming language',
    'long_description': None,
    'author': 'James Butcher',
    'author_email': 'jamesbutcher@duck.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7',
}


setup(**setup_kwargs)



import wcore_py
import click
from pathlib import Path


@click.group()
def cli():
    pass


@cli.command()
@click.argument("path")
def run(path: str) -> None:
    with open(str(Path(".") / path)) as f:
        content = f.read()

    wcore_py.eval(content)


@cli.command()
def shell() -> None:
    state = wcore_py.State()

    while (
        code_block := input(">>> ")
        + "\n"
        + "\n".join(iter(lambda: input("... ").strip(), ""))
    ):
        state.apply(code_block)


if __name__ == "__main__":
    cli()
